# Unpublished File

Keeps public files of a publicly inaccessible entity in the private filesystem
until the entity becomes available for public. Entity files are all files
referred by the entity, either via entity reference fields or uploaded and
embedded in text blobs. More precisely, the module covers all cases configured
by the [Entity Usage](https://www.drupal.org/project/entity_usage) module.

## Configuration

Configure [Entity Usage](https://www.drupal.org/project/entity_usage). Note that
this is critical for the module to work, and it's crucial to understand how
[Entity Usage](https://www.drupal.org/project/entity_usage) works and how to
track the relation between host/source entities, such as _Content_ (`node`), and
_File_ (`file`) entities.

* Visit `/admin/config/entity-usage/settings`.
* Carefully check the entity types under _Enabled source entity types_ section.
  The files visibility depend on the visibility of their source entities (the
  entity that refers the file). Not that the reference is not limited to entity
  reference fields, a reference to a file can be also an image uploaded and
  embedded in a text field, using CKEditor.
* Select the file entity types, under _Enabled target entity types_ section. In
  most of the cases it's only the _File_ (`file`) that should be selected unless
  you have other entity types, implementing `\Drupal\file\FileInterface`.
* Select the tracking plugins under _Enabled tracking plugins_ section. These
  plugins knowing how determine the relation between a source entity (e.g
  `node`) and the target entity (`file`). For instance, if your node-type has
  a file or image field, you should check the _Entity Reference_ plugin. If the
  node body allows also embedding images and files using data attributes, such
  as `drupal-entity-type="file"` and `drupal-entity-uuid="...""`, you should
  check one of _CKEditor Image_ or/and _LinkIt_, accordingly.

## Contribute

### Checkout and install

After checking out with Git, deploy the codebase with Composer

```bash
composer install
```

This will create the following directories and files, outside the VCS control:

* Deploy a full Drupal site under the `./build` directory.
* Create a `Makefile` in the project's root.
* Create a `phpunit.xml` in the project's root.

### Adjust environment variables

Edit `Makefile` and `phpunit.xml` and customize the two files according to your
working environment.

### Install Drupal

```bash
composer install-drupal
```

### Run tests

```bash
./vendor/bin/phpunit
```
