<?php

declare(strict_types = 1);

namespace Drupal\unpublished_file\EventSubscriber;

use Drupal\Core\Config\ConfigCrudEvent;
use Drupal\Core\Config\ConfigEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Listens to Entity Usage module weight change.
 */
class EntityUsageWeightSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [ConfigEvents::SAVE => 'onEntityUsageModuleWeightChange'];
  }

  /**
   * Updates the Unpublished File module weight.
   *
   * This module requires that its hook implementations are running after the
   * ones from Entity Usage. This is achieved be ensuring a higher weight of the
   * module. This subscriber listens to the (unlikely) change of weight of the
   * Entity Usage module and ensures a higher weight.
   *
   * @param \Drupal\Core\Config\ConfigCrudEvent $event
   *   The configuration event.
   */
  public function onEntityUsageModuleWeightChange(ConfigCrudEvent $event): void {
    static $isRecursion = FALSE;
    $config = $event->getConfig();
    if ($config->getName() === 'core.extension') {
      $originalWeight = $config->getOriginal('module')['entity_usage'];
      $actualWeight = $config->get('module')['entity_usage'];
      if (!$isRecursion && $actualWeight !== $originalWeight) {
        // Prevent infinite recursion as the subscriber might listen to config
        // change triggered in module_set_weight().
        // @see module_set_weight()
        $isRecursion = TRUE;
        module_set_weight('unpublished_file', $actualWeight + 5);
      }
    }
  }

}
