<?php

declare(strict_types=1);

namespace Drupal\unpublished_file;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Plugin\PluginBase;
use Drupal\entity_usage\EntityUsageInterface;
use Drupal\file\FileInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Base class for accessible usages plugins.
 */
abstract class FileSourcePluginBase extends PluginBase implements FileSourcePluginInterface, ContainerFactoryPluginInterface {

  /**
   * Constructs a new service instance.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\entity_usage\EntityUsageInterface $entityUsage
   *   The entity usage service.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    protected EntityUsageInterface $entityUsage,
    protected EntityTypeManagerInterface $entityTypeManager,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): self {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_usage.usage'),
      $container->get('entity_type.manager'),
    );
  }


  /**
   * Checks whether a given entity type ID designates a file entity.
   *
   * Check also potential entity types implementing \Drupal\file\FileInterface,
   * other than 'file'.
   *
   * @param string $entityTypeId
   *   The entity type ID to be checked.
   *
   * @return bool
   *   Whether a given entity type ID designates a file entity.
   */
  protected function isFileEntityType(string $entityTypeId): bool {
    return $this->entityTypeManager->getDefinition($entityTypeId)->entityClassImplements(FileInterface::class);
  }

}
