<?php

namespace Drupal\unpublished_file;

use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\file\FileInterface;

/**
 * Interface for FileSource plugins.
 */
interface FileSourcePluginInterface extends PluginInspectionInterface {

  /**
   * Returns a list of accessible source entities for a given file and user.
   *
   * @param \Drupal\file\FileInterface $file
   *   The file entity.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user account being checked.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface[]
   *   A list of host/source entities.
   */
  public function getAccessibleSourceEntities(FileInterface $file, AccountInterface $account): array;

  /**
   * Checks whether the given file has accessible sources.
   *
   * @param \Drupal\file\FileInterface $file
   *   The file entity.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user account being checked.
   *
   * @return bool
   *   Whether the given file has accessible sources.
   */
  public function hasAccessibleSourceEntities(FileInterface $file, AccountInterface $account): bool;

  /**
   * Returns a list of file entities referred by a source entity.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $source
   *   The source entity.
   *
   * @return array[]
   *   An associative array having the file entity type ID as keys and a list of
   *   file entity IDs as values.
   */
  public function getFilesForSource(ContentEntityInterface $source): array;

}
