<?php

declare(strict_types = 1);

namespace Drupal\unpublished_file;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\unpublished_file\Annotation\FileSource;

/**
 * Plugin manager for FileSource plugins.
 */
class FileSourcePluginManager extends DefaultPluginManager {

  /**
   * Constructs a new plugin manager service instance.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheBackend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cacheBackend, ModuleHandlerInterface $moduleHandler) {
    parent::__construct('Plugin/UnpublishedFile/FileSource', $namespaces, $moduleHandler, FileSourcePluginInterface::class, FileSource::class);
    $this->alterInfo('unpublished_file_source_info');
    $this->setCacheBackend($cacheBackend, 'unpublished_file_source');
  }

  /**
   * {@inheritdoc}
   */
  protected function findDefinitions(): array {
    // Override this method instead of ::getDefinitions() because the later
    // returns already cached definitions.
    return array_filter(parent::findDefinitions(), function (array $pluginDefinition): bool {
      if (empty($pluginDefinition['required_modules'])) {
        return TRUE;
      }
      foreach ($pluginDefinition['required_modules'] as $module) {
        if (!$this->moduleHandler->moduleExists($module)) {
          return FALSE;
        }
      }
      return TRUE;
    });
  }

  /**
   * Check whether a plugin can be used.
   *
   * @param array $pluginDefinition
   *   The plugin definition.
   *
   * @return bool
   *   Whether a plugin is usable.
   */
  protected function usePlugin(array $pluginDefinition): bool {
    if (empty($pluginDefinition['required_modules'])) {
      return TRUE;
    }
    foreach ($pluginDefinition['required_modules'] as $module) {
      if (!$this->moduleHandler->moduleExists($module)) {
        return FALSE;
      }
    }
    return TRUE;
  }

}
