<?php

namespace Drupal\unpublished_file;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\file\FileInterface;

/**
 * Interface of 'unpublished_file.service' service.
 */
interface UnpublishedFileInterface {

  /**
   * Moves the source files from public to private file system or vice-versa.
   *
   * @param \Drupal\Core\Entity\EntityInterface $source
   *   The host entity also known as source entity in Entity Usage terminology.
   */
  public function setSourceFilesVisibility(EntityInterface $source): void;

  /**
   * Returns a list of accessible source entities for a given file and user.
   *
   * @param \Drupal\file\FileInterface $file
   *   The file entity.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user account being checked.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface[]
   *   A list of host/source entities.
   */
  public function getAccessibleSourceEntities(FileInterface $file, AccountInterface $account): array;

}
