<?php

declare(strict_types = 1);

namespace Drupal\Tests\unpublished_file\Kernel;

use Drupal\KernelTests\KernelTestBase;

/**
 * @coversDefaultClass \Drupal\unpublished_file\EventSubscriber\EntityUsageWeightSubscriber
 * @group unpublished_file
 */
class ModuleWeightTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['file'];

  /**
   * @covers ::onEntityUsageModuleWeightChange
   */
  public function testModuleWeight(): void {
    $installer = $this->container->get('module_installer');
    // Use installer as kernel tests are not running the install hooks.
    $installer->install(['unpublished_file']);


    // Check that unpublished_file is after entity_usage.
    $config = $this->config('core.extension');
    $this->assertSame(0, $config->get('module')['entity_usage']);
    $this->assertSame(5, $config->get('module')['unpublished_file']);

    module_set_weight('entity_usage', 200);

    // Check that unpublished_file is still after entity_usage.
    $config = $this->config('core.extension');
    $this->assertSame(200, $config->get('module')['entity_usage']);
    $this->assertSame(205, $config->get('module')['unpublished_file']);
  }

}
